@@ -4,7 +4,7 @@ use warnings;
 use Module::Pluggable::Object;
 use Test::More ();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Exporter;
 our @ISA    = qw/Exporter/;
@@ -36,20 +36,51 @@ sub all_ok {
     Test::More::plan('no_plan');
     my @exceptions = @{ $param{except} || [] };
 
+    if ($param{fork}) {
+        require Test::SharedFork;
+        Test::More::note("Tests run under forking. Parent PID=$$");
+    }
+
     for my $class (
         grep { !_is_excluded( $_, @exceptions ) }
             _classes($search_path, \%param) ) {
 
         for my $check (@checks) {
-            Test::More::ok(
-                $check->{test}->($class),
-                "$check->{name}$class",
-            );
+            _exec_test($check, $class, $param{fork});
         }
 
     }
 }
 
+sub _exec_test {
+    my ($check, $class, $fork) = @_;
+
+    unless ($fork) {
+        _ok($check, $class);
+        return;
+    }
+
+    my $pid = fork();
+    die 'could not fork' unless defined $pid;
+
+    if ($pid) {
+        waitpid($pid, 0);
+    }
+    else {
+        _ok($check, $class, $fork);
+        exit;
+    }
+}
+
+sub _ok {
+    my ($check, $class, $fork) = @_;
+
+    Test::More::ok(
+        $check->{test}->($class),
+        "$check->{name}$class". ( $fork && $fork == 2 ? "(PID=$$)" : '' )
+    );
+}
+
 sub _classes {
     my ($search_path, $param) = @_;
 
@@ -146,7 +177,11 @@ Test::AllModules - do some tests for modules in search path
             lib => [
                 'lib',
                 't/lib',
-            ]
+            ],
+
+            shuffle => 1, # shuffle a use list: optional
+
+            fork => 1,    # use each module after forking: optional
         );
     }
 
